import React, {useRef, useEffect} from 'react';

import {Text, View, StyleSheet, TextInput, Platform} from 'react-native';

const CountDown = ({initialSeconds}) => {
  const textRef = useRef(null);
  const textRef1 = useRef(null);
  const textRef2 = useRef(null);
  const textRef3 = useRef(null);
  const secondsRef = useRef(initialSeconds);
  useEffect(() => {
    const formatTime = totalSeconds => {
      const d = Math.floor(totalSeconds / (60 * 60 * 24));
      const h = Math.floor((totalSeconds % (60 * 60 * 24)) / (60 * 60));
      const m = Math.floor((totalSeconds % (60 * 60)) / 60);
      const s = totalSeconds % 60;

      // return `${days}d ${hours}h ${minutes}m ${seconds}s`;

      const dDisplay = d > 0 ? d.toLocaleString('en-US', {minimumIntegerDigits: 2, useGrouping: false}) + ';' : '00;';
      const hDisplay = h > 0 ? h.toLocaleString('en-US', {minimumIntegerDigits: 2, useGrouping: false}) + ';' : '00;';
      const mDisplay = m > 0 ? m.toLocaleString('en-US', {minimumIntegerDigits: 2, useGrouping: false}) + ';' : '00;';
      const sDisplay = s > 0 ? s.toLocaleString('en-US', {minimumIntegerDigits: 2, useGrouping: false}) + ';' : '00;';
      return dDisplay + hDisplay + mDisplay + sDisplay;
    };

    const updateText = () => {
      const custom_time = formatTime(secondsRef.current).split(';');

      if (textRef.current) {
        textRef.current.setNativeProps({text: custom_time[0]});
      }
      if (textRef1.current) {
        textRef1.current.setNativeProps({text: custom_time[1]});
      }
      if (textRef2.current) {
        textRef2.current.setNativeProps({text: custom_time[2]});
      }
      if (textRef3.current) {
        textRef3.current.setNativeProps({text: custom_time[3]});
      }
    };

    updateText();

    const interval = setInterval(() => {
      secondsRef.current -= 1;
      if (secondsRef.current >= 0) {
        updateText();
      } else {
        clearInterval(interval);
      }
    }, 1000);

    return () => clearInterval(interval);
  }, []);

  return (
    <View style={{flexDirection: 'row', marginTop: 5}}>
      <View style={styles.wrap1}>
        <View style={styles.container1}>
          <TextInput editable={false} ref={textRef} style={[styles.text, Platform.OS==='android'? styles.text2:{}]}></TextInput>
        </View>
        <Text style={styles.text1}>J</Text>
      </View>
      <View style={styles.wrap1}>
        <View style={styles.container1}>
          <TextInput editable={false} ref={textRef1} style={[styles.text, Platform.OS==='android'? styles.text2:{}]}></TextInput>
        </View>
        <Text style={styles.text1}>H</Text>
      </View>
      <View style={styles.wrap1}>
        <View style={styles.container1}>
          <TextInput editable={false} ref={textRef2} style={[styles.text, Platform.OS==='android'? styles.text2:{}]}></TextInput>
        </View>
        <Text style={styles.text1}>Min</Text>
      </View>
      <View style={styles.wrap1}>
        <View style={styles.container1}>
          <TextInput editable={false} ref={textRef3} style={[styles.text, Platform.OS==='android'? styles.text2:{}]}></TextInput>
        </View>
        <Text style={styles.text1}>Sec</Text>
      </View>
    </View>
  );
};

const styles = StyleSheet.create({
  text: {
    fontWeight: '700',
    fontSize: 12,
    color: '#ffffff',
  },
  container1: {
    justifyContent: 'center',
    backgroundColor: '#D70073',
    borderRadius: 5,
    alignItems: 'center',
    paddingVertical: 3,
    paddingHorizontal: 5,
  },
  text1: {fontWeight: '600', fontSize: 10, color: '#D70073', marginLeft: 2},
  wrap1: {flexDirection: 'row', alignItems: 'center', marginRight: 5},
  text2:{paddingBottom:5,height:28,textAlign:'center'}
});

export default CountDown;
